import mythic_container
from mythic_container.logging import logger

MYTHIC_RPC_TASK_DISPLAY_TO_REAL_ID_SEARCH = "mythic_rpc_task_display_to_real_id_search"


class MythicRPCTaskDisplayToRealIdSearchMessage:
    def __init__(self,
                 TaskDisplayID: int,
                 OperationName: str = "",
                 OperationID: int = None,
                 **kwargs):
        self.TaskDisplayID = TaskDisplayID
        self.OperationName = OperationName
        self.OperationID = OperationID
        for k, v in kwargs.items():
            logger.info(f"Unknown kwarg {k} - {v}")

    def to_json(self):
        return {
            "task_display_id": self.TaskDisplayID,
            "operation_name": self.OperationName,
            "operation_id": self.OperationID,
        }

class MythicRPCTaskDisplayToRealIdSearchMessageResponse:

    def __init__(self,
                 success: bool = False,
                 error: str = "",
                 task_id: int = 0,
                 **kwargs):
        self.Success = success
        self.Error = error
        self.TaskID = task_id
        for k, v in kwargs.items():
            logger.info(f"Unknown kwarg {k} - {v}")


async def SendMythicRPCTaskDisplayToRealIdSearch(
        msg: MythicRPCTaskDisplayToRealIdSearchMessage) -> MythicRPCTaskDisplayToRealIdSearchMessageResponse:
    response = await mythic_container.RabbitmqConnection.SendRPCDictMessage(queue=MYTHIC_RPC_TASK_DISPLAY_TO_REAL_ID_SEARCH,
                                                                            body=msg.to_json())
    return MythicRPCTaskDisplayToRealIdSearchMessageResponse(**response)



import mythic_container
from mythic_container.logging import logger
import base64

MYTHIC_RPC_RESPONSE_CREATE = "mythic_rpc_response_create"


class MythicRPCResponseCreateMessage:
    def __init__(self,
                 TaskID: int,
                 Response: bytes,
                 **kwargs):
        self.TaskID = TaskID
        self.Response = Response
        for k, v in kwargs.items():
            logger.info(f"Unknown kwarg {k} - {v}")

    def to_json(self):
        return {
            "task_id": self.TaskID,
            "response": base64.b64encode(self.Response).decode()
        }


class MythicRPCResponseCreateMessageResponse:
    def __init__(self,
                 success: bool = False,
                 error: str = "",
                 **kwargs):
        self.Success = success
        self.Error = error
        for k, v in kwargs.items():
            logger.info(f"Unknown kwarg {k} - {v}")


async def SendMythicRPCResponseCreate(
        msg: MythicRPCResponseCreateMessage) -> MythicRPCResponseCreateMessageResponse:
    response = await mythic_container.RabbitmqConnection.SendRPCDictMessage(queue=MYTHIC_RPC_RESPONSE_CREATE,
                                                                            body=msg.to_json())
    return MythicRPCResponseCreateMessageResponse(**response)



import mythic_container
from mythic_container.logging import logger

MYTHIC_RPC_CREDENTIAL_CREATE = "mythic_rpc_credential_create"


class MythicRPCCredentialData:
    def __init__(self,
                 CredentialType: str = None,
                 Realm: str = None,
                 Account: str = None,
                 Credential: str = None,
                 Comment: str = None,
                 ExtraData: str = None,
                 **kwargs):
        self.CredentialType = CredentialType
        self.Realm = Realm
        self.Account = Account
        self.Credential = Credential
        self.Comment = Comment
        self.ExtraData = ExtraData
        for k, v in kwargs.items():
            logger.info(f"Unknown kwarg {k} - {v}")
    def to_json(self):
        return {
            "credential_type": self.CredentialType,
            "realm": self.Realm,
            "account": self.Account,
            "credential": self.Credential,
            "comment": self.Comment,
            "metadata": self.ExtraData
        }

class MythicRPCCredentialCreateMessage:
    def __init__(self,
                 TaskID: int,
                 Credentials: list[MythicRPCCredentialData] = None,
                 **kwargs):
        self.TaskID = TaskID
        self.Credentials = Credentials
        for k, v in kwargs.items():
            logger.info(f"Unknown kwarg {k} - {v}")

    def to_json(self):
        return {
            "task_id": self.TaskID,
            "credentials": [x.to_json() for x in self.Credentials],
        }


class MythicRPCCredentialCreateMessageResponse:
    def __init__(self,
                 success: bool = False,
                 error: str = "",
                 **kwargs):
        self.Success = success
        self.Error = error
        for k, v in kwargs.items():
            logger.info(f"Unknown kwarg {k} - {v}")


async def SendMythicRPCCredentialCreate(
        msg: MythicRPCCredentialCreateMessage) -> MythicRPCCredentialCreateMessageResponse:
    response = await mythic_container.RabbitmqConnection.SendRPCDictMessage(queue=MYTHIC_RPC_CREDENTIAL_CREATE,
                                                                            body=msg.to_json())
    return MythicRPCCredentialCreateMessageResponse(**response)



import pathlib
from enum import Enum
from abc import abstractmethod
import json
from collections.abc import Awaitable, Callable
from .logging import logger
import base64
import sys


class C2OPSECMessage:
    def __init__(self,
                 c2_profile_name: str,
                 parameters: dict,
                 **kwargs):
        self.Name = c2_profile_name
        self.Parameters = parameters
        for k,v in kwargs.items():
            logger.error(f"unknown kwarg {k} {v}")
    def to_json(self):
        return {
            "c2_profile_name": self.Name,
            "parameters": self.Parameters
        }
class C2OPSECMessageResponse:
    def __init__(self,
                 Success: bool,
                 Error: str = "",
                 Message: str = "",
                 **kwargs):
        self.Success = Success
        self.Error = Error
        self.Message = Message
        for k,v in kwargs.items():
            logger.error(f"unknown kwarg {k} {v}")
    def to_json(self):
        return {
            "success": self.Success,
            "error": self.Error,
            "message": self.Message
        }
class C2ConfigCheckMessage:
    def __init__(self,
                 c2_profile_name: str,
                 parameters: dict,
                 **kwargs):
        self.Name = c2_profile_name
        self.Parameters = parameters
        for k,v in kwargs.items():
            logger.error(f"unknown kwarg {k} {v}")
    def to_json(self):
        return {
            "c2_profile_name": self.Name,
            "parameters": self.Parameters
        }
class C2ConfigCheckMessageResponse:
    def __init__(self,
                 Success: bool,
                 Error: str = "",
                 Message: str = "",
                 **kwargs):
        self.Success = Success
        self.Error = Error
        self.Message = Message
        for k,v in kwargs.items():
            logger.error(f"unknown kwarg {k} {v}")
    def to_json(self):
        return {
            "success": self.Success,
            "error": self.Error,
            "message": self.Message
        }
class C2GetDebugOutputMessage:
    def __init__(self,
                 c2_profile_name: str,
                 **kwargs):
        self.Name = c2_profile_name
        for k,v in kwargs.items():
            logger.error(f"unknown kwarg {k} {v}")
    def to_json(self):
        return {
            "c2_profile_name": self.Name,
        }
class C2GetDebugOutputMessageResponse:
    def __init__(self,
                 Success: bool,
                 Error: str = "",
                 Message: str = "",
                 InternalServerRunning: bool = False,
                 **kwargs):
        self.Success = Success
        self.Error = Error
        self.Message = Message
        self.InternalServerRunning = InternalServerRunning
        for k,v in kwargs.items():
            logger.error(f"unknown kwarg {k} {v}")
    def to_json(self):
        return {
            "success": self.Success,
            "error": self.Error,
            "message": self.Message,
            "server_running": self.InternalServerRunning
        }
class C2GetFileMessage:
    def __init__(self,
                 c2_profile_name: str,
                 filename: str,
                 **kwargs):
        self.Name = c2_profile_name
        self.Filename = filename
        for k,v in kwargs.items():
            logger.error(f"unknown kwarg {k} {v}")
    def to_json(self):
        return {
            "c2_profile_name": self.Name,
            "filename": self.Filename
        }
class C2GetFileMessageResponse:
    def __init__(self,
                 Success: bool,
                 Error: str = "",
                 Message: bytes = b"",
                 **kwargs):
        self.Success = Success
        self.Error = Error
        self.Message = Message
        for k,v in kwargs.items():
            logger.error(f"unknown kwarg {k} {v}")
    def to_json(self):
        return {
            "success": self.Success,
            "error": self.Error,
            "message": base64.b64encode(self.Message).decode(),
        }
class C2GetRedirectorRulesMessage:
    def __init__(self,
                 c2_profile_name: str,
                 parameters: dict,
                 **kwargs):
        self.Name = c2_profile_name
        self.Parameters = parameters
        for k,v in kwargs.items():
            logger.error(f"unknown kwarg {k} {v}")
    def to_json(self):
        return {
            "c2_profile_name": self.Name,
            "parameters": self.Parameters
        }
class C2GetRedirectorRulesMessageResponse:
    def __init__(self,
                 Success: bool,
                 Error: str = "",
                 Message: str = "",
                 **kwargs):
        self.Success = Success
        self.Error = Error
        self.Message = Message
        for k,v in kwargs.items():
            logger.error(f"unknown kwarg {k} {v}")
    def to_json(self):
        return {
            "success": self.Success,
            "error": self.Error,
            "message": self.Message
        }
class C2ListFileMessage:
    def __init__(self,
                 c2_profile_name: str,
                 **kwargs):
        self.Name = c2_profile_name
        for k,v in kwargs.items():
            logger.error(f"unknown kwarg {k} {v}")
    def to_json(self):
        return {
            "c2_profile_name": self.Name,
        }
class C2ListFileMessageResponse:
    def __init__(self,
                 Success: bool,
                 Error: str = "",
                 Files: list[str] = [],
                 **kwargs):
        self.Success = Success
        self.Error = Error
        self.Files = Files
        for k,v in kwargs.items():
            logger.error(f"unknown kwarg {k} {v}")
    def to_json(self):
        return {
            "success": self.Success,
            "error": self.Error,
            "files": self.Files,
        }
class C2RemoveFileMessage:
    def __init__(self,
                 c2_profile_name: str,
                 filename: str,
                 **kwargs):
        self.Name = c2_profile_name
        self.Filename = filename
        for k,v in kwargs.items():
            logger.error(f"unknown kwarg {k} {v}")
    def to_json(self):
        return {
            "c2_profile_name": self.Name,
            "filename": self.Filename
        }
class C2RemoveFileMessageResponse:
    def __init__(self,
                 Success: bool,
                 Error: str = "",
                 **kwargs):
        self.Success = Success
        self.Error = Error
        for k,v in kwargs.items():
            logger.error(f"unknown kwarg {k} {v}")
    def to_json(self):
        return {
            "success": self.Success,
            "error": self.Error,
        }
class C2StartServerMessage:
    def __init__(self,
                 c2_profile_name: str,
                 **kwargs):
        self.Name = c2_profile_name
        for k,v in kwargs.items():
            logger.error(f"unknown kwarg {k} {v}")
    def to_json(self):
        return {
            "c2_profile_name": self.Name,
        }
class C2StartServerMessageResponse:
    def __init__(self,
                 Success: bool,
                 Error: str = "",
                 Message: str = "",
                 InternalServerRunning: bool = False,
                 **kwargs):
        self.Success = Success
        self.Error = Error
        self.Message = Message
        self.InternalServerRunning = InternalServerRunning
        for k,v in kwargs.items():
            logger.error(f"unknown kwarg {k} {v}")
    def to_json(self):
        return {
            "success": self.Success,
            "error": self.Error,
            "message": self.Message,
            "server_running": self.InternalServerRunning
        }
class C2StopServerMessage:
    def __init__(self,
                 c2_profile_name: str,
                 **kwargs):
        self.Name = c2_profile_name
        for k,v in kwargs.items():
            logger.error(f"unknown kwarg {k} {v}")
    def to_json(self):
        return {
            "c2_profile_name": self.Name,
        }
class C2StopServerMessageResponse:
    def __init__(self,
                 Success: bool,
                 Error: str = "",
                 Message: str = "",
                 InternalServerRunning: bool = False,
                 **kwargs):
        self.Success = Success
        self.Error = Error
        self.Message = Message
        self.InternalServerRunning = InternalServerRunning
        for k,v in kwargs.items():
            logger.error(f"unknown kwarg {k} {v}")
    def to_json(self):
        return {
            "success": self.Success,
            "error": self.Error,
            "message": self.Message,
            "server_running": self.InternalServerRunning
        }
class C2WriteFileMessage:
    def __init__(self,
                 c2_profile_name: str,
                 filename: str,
                 contents: str,
                 **kwargs):
        self.Name = c2_profile_name
        self.Filename = filename
        self.Contents = base64.b64decode(contents)
        for k,v in kwargs.items():
            logger.error(f"unknown kwarg {k} {v}")
    def to_json(self):
        return {
            "c2_profile_name": self.Name,
            "filename": self.Filename,
            "contents": base64.b64encode(self.Contents)
        }
class C2WriteFileMessageResponse:
    def __init__(self,
                 Success: bool,
                 Error: str = "",
                 Message: bytes = b"",
                 **kwargs):
        self.Success = Success
        self.Error = Error
        self.Message = Message
        for k,v in kwargs.items():
            logger.error(f"unknown kwarg {k} {v}")
    def to_json(self):
        return {
            "success": self.Success,
            "error": self.Error,
            "message": self.Message,
        }
class C2OtherServiceRPCMessage:
    def __init__(self,
                 ServiceName: str = None,
                 service_name: str = None,
                 ServiceRPCFunction: str = None,
                 service_function: str = None,
                 ServiceRPCFunctionArguments: dict = None,
                 service_arguments: dict = None,
                 **kwargs):
        self.ServiceName = ServiceName
        if self.ServiceName is None:
            self.ServiceName = service_name
        self.ServiceRPCFunction = ServiceRPCFunction
        if self.ServiceRPCFunction is None:
            self.ServiceRPCFunction = service_function
        self.ServiceRPCFunctionArguments = ServiceRPCFunctionArguments
        if self.ServiceRPCFunctionArguments is None:
            self.ServiceRPCFunctionArguments = service_arguments
        for k, v in kwargs.items():
            logger.error(f"unknown kwarg {k} {v}")
    def to_json(self):
        return {
            "service_name": self.ServiceName,
            "service_function": self.ServiceRPCFunction,
            "service_arguments": self.ServiceRPCFunctionArguments
        }
class C2OtherServiceRPCMessageResponse:
    def __init__(self,
                 success: bool = None,
                 error: str = None,
                 result: dict = None,
                 Success: bool = None,
                 Error: str = None,
                 Result: dict = None,
                 **kwargs):
        self.Success = Success
        if self.Success is None:
            self.Success = success
        self.Error = Error
        if self.Error is None:
            self.Error = error
        self.Result = Result
        if self.Result is None:
            self.Result = result
        for k, v in kwargs.items():
            logger.error(f"unknown kwarg {k} {v}")
    def to_json(self):
        return {
            "success": self.Success,
            "error": self.Error,
            "result": self.Result
        }


class ParameterType(Enum):
    String = "String"
    ChooseOne = "ChooseOne"
    Array = "Array"
    Date = "Date"
    Dictionary = "Dictionary"
    Boolean = "Boolean"


class C2ProfileParameter:
    def __init__(
        self,
        name: str,
        description: str,
        default_value: str = None,
        randomize: bool = False,
        format_string: str = "",
        parameter_type: ParameterType = ParameterType.String,
        required: bool = True,
        verifier_regex: str = "",
        choices: [str] = None,
        crypto_type: bool = False,
    ):
        self.name = name
        self.description = description
        self.randomize = randomize
        self.format_string = format_string
        self.parameter_type = parameter_type
        self.required = required
        self.verifier_regex = verifier_regex
        self.choices = choices
        self.default_value = default_value
        self.crypto_type = crypto_type


    def to_json(self):
        return {
            "name": self.name,
            "description": self.description,
            "default_value": self.default_value if self.parameter_type not in [ParameterType.Array, ParameterType.Dictionary] else json.dumps(self.default_value),
            "randomize": self.randomize,
            "format_string": self.format_string,
            "required": self.required,
            "parameter_type": self.parameter_type.value,
            "verifier_regex": self.verifier_regex,
            "crypto_type": self.crypto_type,
            "choices": self.choices,
        }


class C2Profile:

    async def opsec(self, inputMsg: C2OPSECMessage) -> C2OPSECMessageResponse:
        response = C2OPSECMessageResponse(Success=True)
        response.Message = "Not Implemented, passing by default"
        response.Message += f"\nInput: {json.dumps(inputMsg.to_json(), indent=4)}"
        return response

    async def config_check(self, inputMsg: C2ConfigCheckMessage) -> C2ConfigCheckMessageResponse:
        response = C2ConfigCheckMessageResponse(Success=True)
        response.Message = "Not Implemented"
        response.Message += f"\nInput: {json.dumps(inputMsg.to_json(), indent=4)}"
        return response

    async def redirect_rules(self, inputMsg: C2GetRedirectorRulesMessage) -> C2GetRedirectorRulesMessageResponse:
        response = C2GetRedirectorRulesMessageResponse(Success=True)
        response.Message = "Not Implemented"
        response.Message += f"\nInput: {json.dumps(inputMsg.to_json(), indent=4)}"
        return response

    custom_rpc_functions: dict[str, Callable[[C2OtherServiceRPCMessage], Awaitable[C2OtherServiceRPCMessageResponse]]] = {}
    server_folder_path: pathlib.Path
    server_binary_path: pathlib.Path

    @property
    @abstractmethod
    def name(self):
        pass

    @property
    @abstractmethod
    def description(self):
        pass

    @property
    @abstractmethod
    def author(self):
        pass

    @property
    @abstractmethod
    def is_p2p(self):
        pass

    @property
    @abstractmethod
    def is_server_routed(self):
        pass

    @property
    @abstractmethod
    def parameters(self):
        pass

    def to_json(self):
        if self.server_binary_path is None:
            logger.exception("Must supply server_binary_path as pathlib.Path pointing to the binary to run when the server starts")
            sys.exit(1)
        elif not isinstance(self.server_binary_path, pathlib.Path):
            logger.exception("Wrong type for server_binary_path - should be pathlib.Path")
            sys.exit(1)
        elif self.server_folder_path is None:
            logger.exception("Must supply server_folder_path as pathlib.Path pointing to folder where your c2 files exist")
            sys.exit(1)
        elif not isinstance(self.server_folder_path, pathlib.Path):
            logger.exception("Wrong type for server_folder_path - should be pathlib.Path")
            sys.exit(1)
        return {
            "c2_profile": {
                "name": self.name,
                "description": self.description,
                "author": self.author,
                "is_p2p": self.is_p2p,
                "is_server_routed": self.is_server_routed,
            },
            "parameters": [x.to_json() for x in self.parameters]
        }

c2Profiles: dict[str, C2Profile] = {}
runningServers: dict[str, dict] = {}


# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

import mythic_container.grpc.translationContainerGRPC_pb2 as translationContainerGRPC__pb2


class TranslationContainerStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.TranslateFromCustomToMythicFormat = channel.stream_stream(
                '/translationContainerServices.TranslationContainer/TranslateFromCustomToMythicFormat',
                request_serializer=translationContainerGRPC__pb2.TrCustomMessageToMythicC2FormatMessageResponse.SerializeToString,
                response_deserializer=translationContainerGRPC__pb2.TrCustomMessageToMythicC2FormatMessage.FromString,
                )
        self.TranslateFromMythicToCustomFormat = channel.stream_stream(
                '/translationContainerServices.TranslationContainer/TranslateFromMythicToCustomFormat',
                request_serializer=translationContainerGRPC__pb2.TrMythicC2ToCustomMessageFormatMessageResponse.SerializeToString,
                response_deserializer=translationContainerGRPC__pb2.TrMythicC2ToCustomMessageFormatMessage.FromString,
                )
        self.GenerateEncryptionKeys = channel.stream_stream(
                '/translationContainerServices.TranslationContainer/GenerateEncryptionKeys',
                request_serializer=translationContainerGRPC__pb2.TrGenerateEncryptionKeysMessageResponse.SerializeToString,
                response_deserializer=translationContainerGRPC__pb2.TrGenerateEncryptionKeysMessage.FromString,
                )


class TranslationContainerServicer(object):
    """Missing associated documentation comment in .proto file."""

    def TranslateFromCustomToMythicFormat(self, request_iterator, context):
        """rpc function(messageFromClient) messageToClient
        all of these functions start off by sending messageToClient and getting the result back
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def TranslateFromMythicToCustomFormat(self, request_iterator, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GenerateEncryptionKeys(self, request_iterator, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_TranslationContainerServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'TranslateFromCustomToMythicFormat': grpc.stream_stream_rpc_method_handler(
                    servicer.TranslateFromCustomToMythicFormat,
                    request_deserializer=translationContainerGRPC__pb2.TrCustomMessageToMythicC2FormatMessageResponse.FromString,
                    response_serializer=translationContainerGRPC__pb2.TrCustomMessageToMythicC2FormatMessage.SerializeToString,
            ),
            'TranslateFromMythicToCustomFormat': grpc.stream_stream_rpc_method_handler(
                    servicer.TranslateFromMythicToCustomFormat,
                    request_deserializer=translationContainerGRPC__pb2.TrMythicC2ToCustomMessageFormatMessageResponse.FromString,
                    response_serializer=translationContainerGRPC__pb2.TrMythicC2ToCustomMessageFormatMessage.SerializeToString,
            ),
            'GenerateEncryptionKeys': grpc.stream_stream_rpc_method_handler(
                    servicer.GenerateEncryptionKeys,
                    request_deserializer=translationContainerGRPC__pb2.TrGenerateEncryptionKeysMessageResponse.FromString,
                    response_serializer=translationContainerGRPC__pb2.TrGenerateEncryptionKeysMessage.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'translationContainerServices.TranslationContainer', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class TranslationContainer(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def TranslateFromCustomToMythicFormat(request_iterator,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.stream_stream(request_iterator, target, '/translationContainerServices.TranslationContainer/TranslateFromCustomToMythicFormat',
            translationContainerGRPC__pb2.TrCustomMessageToMythicC2FormatMessageResponse.SerializeToString,
            translationContainerGRPC__pb2.TrCustomMessageToMythicC2FormatMessage.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def TranslateFromMythicToCustomFormat(request_iterator,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.stream_stream(request_iterator, target, '/translationContainerServices.TranslationContainer/TranslateFromMythicToCustomFormat',
            translationContainerGRPC__pb2.TrMythicC2ToCustomMessageFormatMessageResponse.SerializeToString,
            translationContainerGRPC__pb2.TrMythicC2ToCustomMessageFormatMessage.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GenerateEncryptionKeys(request_iterator,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.stream_stream(request_iterator, target, '/translationContainerServices.TranslationContainer/GenerateEncryptionKeys',
            translationContainerGRPC__pb2.TrGenerateEncryptionKeysMessageResponse.SerializeToString,
            translationContainerGRPC__pb2.TrGenerateEncryptionKeysMessage.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)
